@@ -19,9 +19,6 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 # max file size to accept
 MAX_FILE_SIZE = 1048576
 
-# Max commits to scan on a prepush
-MAX_PREPUSH_COMMITS = 100
-
 CPU_COUNT = os.cpu_count() or 1
 
 
@@ -46,6 +43,9 @@ class Config:
     paths_ignore: Set
     show_secrets: bool
     verbose: bool
+    allow_self_signed: bool
+    max_commits_for_hook: int
+    banlisted_detectors: Set[str]
 
     CONFIG_LOCAL = ["./.gitguardian", "./.gitguardian.yml", "./.gitguardian.yaml"]
     CONFIG_GLOBAL = [
@@ -55,17 +55,20 @@ class Config:
     ]
     DEFAULT_CONFIG_LOCAL = "./.gitguardian.yaml"
 
-    attributes: List[Attribute] = [
-        Attribute("all_policies", False),
-        Attribute("api_url", "https://api.gitguardian.com"),
-        Attribute("exit_zero", False),
-        Attribute("matches_ignore", list()),
-        Attribute("paths_ignore", set()),
-        Attribute("show_secrets", False),
-        Attribute("verbose", False),
-    ]
-
     def __init__(self) -> None:
+        self.attributes: List[Attribute] = [
+            Attribute("all_policies", False),
+            Attribute("api_url", "https://api.gitguardian.com"),
+            Attribute("exit_zero", False),
+            Attribute("matches_ignore", list()),
+            Attribute("paths_ignore", set()),
+            Attribute("show_secrets", False),
+            Attribute("verbose", False),
+            Attribute("allow_self_signed", False),
+            Attribute("max_commits_for_hook", 50),
+            Attribute("banlisted_detectors", set()),
+        ]
+
         for attr in self.attributes:
             setattr(self, attr.name, attr.default)
         self.load_configs(self.CONFIG_GLOBAL)
